CareFeature

Enum CareFeature 

pub enum CareFeature {
    DailyHousekeeping,
    PottyWalks,
    Bedding,
    PawgressReport,
    FeedingSupport,
    MedicationSupport,
}
Domain vocabulary for care feature decisions in operations workflows.

Variants



DailyHousekeeping

Daily housekeeping operations signal for labor, capacity, or task planning.



PottyWalks

Potty walks operations signal for labor, capacity, or task planning.



Bedding

Bedding operations signal for labor, capacity, or task planning.



PawgressReport

Progress report shared with the customer during care.



FeedingSupport

Feeding support operations signal for labor, capacity, or task planning.



MedicationSupport

Medication support operations signal for labor, capacity, or task planning.